<?php
/**
 * Plugin Name:       Header Promo
 * Plugin URI:        https://wordpress.org/plugins/my-pricing-table
 * Description:       Make beautiful Promotion Bar with this plugin.
 * Version:           1.0.2
 * Requires at least: 5.2
 * Author:            bPlugins LLC
 * Author URI:        https://bplugins.com
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       header-promo
 */

//  Initialize Plugin
define( 'BPHP_PLUGIN_DIR', WP_PLUGIN_URL . '/' . plugin_basename( dirname( __FILE__ ) ) . '/' );
define( 'BPHP_PLUGIN_VERSION', '1.0.2' );

// Text-domain
add_action( 'plugin_loaded', 'bphp_textdomain' );
function bphp_textdomain() {
    load_textdomain( 'header-promo', BPHP_PLUGIN_DIR . 'languages' );
}

// REGISTER STYLE AND SCRIPT
function bphp_register_assets() {
    wp_register_style( 'bphp_googlefont', '//fonts.googleapis.com/css?family=Open+Sans:300,400)' );
    wp_register_style( 'bphp_header_promo_css', plugin_dir_url( __FILE__ ) . 'public/assets/css/header-promo.css' );
    
    wp_register_style('bphp_downCount_css', plugin_dir_url( __FILE__ ) . 'public/assets/css/downCount.css' );
    wp_enqueue_style( 'bphp_header_promo_css' );
    wp_enqueue_style( 'bphp_downCount_css' );
    wp_enqueue_style( 'bphp_googlefont' );

    wp_register_script( 'bphp_header_promo_js', plugin_dir_url( __FILE__ ) . 'public/assets/js/header-promo.js', ['jquery'], true );
    wp_register_script( 'bphp_downCount_js', plugin_dir_url( __FILE__ ) . 'public/assets/js/jquery.downCount.js', ['jquery'], true );
    wp_enqueue_script( 'bphp_header_promo_js' );
    wp_enqueue_script( 'bphp_downCount_js' );

}
add_action( 'wp_enqueue_scripts', 'bphp_register_assets' );


$bphp_options     = get_option( 'bphp_promo' );
$promo_positions  = isset( $bphp_options['header_promo_pos']) ? $bphp_options['header_promo_pos']: NULL;

function bphp_header_promo() { 
  $bphp_option = get_option( 'bphp_promo' );
  ?>
<?php if( $bphp_option['promo_header_off_on'] !== '0'): ?>
<!-- demo Style 1 -->
<?php if( $bphp_option['header_promo_style'] === 'style_1'): ?>
<div id="promo-outer">
    <div id="promo-inner">
        <span class="promo_txt"><?php echo esc_html($bphp_option['header_promo_text']); ?></span>
        <?php if( $bphp_option['promo_countdown_off_on'] === '1'): ?>
        <!-- Countdown -->
        <?php bphp_countdown_html_markup(); ?>

      <?php endif; ?>
      <a href="<?php echo esc_url($bphp_option['promo_btn_link']); ?>" class="promo_btn" target="_blank"><?php echo esc_html($bphp_option['promo_btn_text']); ?></a>
      <span id="close"><?php echo esc_html__('x', 'header-promo'); ?></span>

    </div>

</div>
<!-- Demo Style 2 -->
<?php elseif( $bphp_option['header_promo_style'] === 'style_2' ): ?>
  <div id="promo-outer">
    <div id="promo-inner">
      <?php if( $bphp_option['promo_countdown_off_on'] === '1'): ?>
        <!-- Countdown -->
        <?php bphp_countdown_html_markup(); ?>

        <?php endif; ?>
      <span class="promo_txt"><?php echo esc_html($bphp_option['header_promo_text']); ?></span>

      <a href="<?php echo esc_url($bphp_option['promo_btn_link']); ?>" class="promo_btn" target="_blank"><?php echo esc_html($bphp_option['promo_btn_text']); ?></a>
      <span id="close"><?php echo esc_html__('x', 'header-promo') ?></span>

    </div>

</div>
<!-- Demo Style 3 -->
<?php elseif( $bphp_option['header_promo_style'] === 'style_3' ): ?>
  <div id="promo-outer">

    <div id="promo-inner">
      <span class="promo_txt"><?php echo esc_html($bphp_option['header_promo_text']); ?></span>
      <a href="<?php echo esc_url($bphp_option['promo_btn_link']); ?>" class="promo_btn" target="_blank"><?php echo esc_html($bphp_option['promo_btn_text']); ?></a>
      <span id="close"><?php echo esc_html__('x', 'header-promo') ?></span>
    </div>

  </div>
<?php else: ?>

<?php endif; ?>

<?php endif; ?> <!-- End of Promotion Bar -->
<?php 
}
add_action( "$promo_positions", 'bphp_header_promo' );


function bphp_header_promo_style() { 
  $bphp_style = get_option( 'bphp_promo' );
  $promo_position  = isset($bphp_style['header_promo_pos'])? $bphp_style['header_promo_pos']: null;

// Header Promo Style
if($promo_position === 'wp_footer'){ ?>
  <style>
    #promo-outer {
      position: fixed;
      bottom: 0;
      left: 0;
      z-index: 9999;
    }
  </style>
  <?php }  ?>
  <style>
    #promo-outer {
      background: <?php echo esc_attr($bphp_style['header_promo_bg']); ?>;
    }
    #promo-inner span.promo_txt{
      font-size: <?php echo esc_attr($bphp_style['promo_text_size']); ?>px;
      color: <?php echo esc_attr($bphp_style['promo_text_color']); ?>;
      font-style: <?php echo esc_attr($bphp_style['promo_text_style']); ?>;
      font-weight: <?php echo esc_attr($bphp_style['promo_text_weight']); ?>;
    }
    #promo-inner .promo_btn {
      background: <?php echo esc_attr($bphp_style['promo_btn_color']); ?>;
      color: <?php echo esc_attr($bphp_style['promo_btn_text_color']); ?>;
      font-size: <?php echo esc_attr($bphp_style['promo_btn_text_size']); ?>px;
      border-radius: <?php echo esc_attr($bphp_style['promo_btn_radius']); ?>px;
    }
    #promo-inner a.promo_btn:hover {
      background: <?php echo esc_attr($bphp_style['promo_btn_hover']); ?>;
    }
    /* Countdown */
    ul.countdown {
      background: <?php echo esc_attr($bphp_style['promo_count_bg']); ?>;
    }
    .days, 
    .hours, 
    .minutes, 
    .seconds {
      background: <?php echo esc_attr($bphp_style['promo_time_bg']); ?>;;
      font-weight: <?php echo esc_attr($bphp_style['promo_time_text_weight']); ?>;;
      font-size: <?php echo esc_attr($bphp_style['promo_time_text_size']); ?>px;
      border-style: solid;
      border-width: <?php echo esc_attr($bphp_style['promo_time_border_width']); ?>px;
      border-color: <?php echo esc_attr($bphp_style['promo_time_border_clr']); ?>;
      border-radius: <?php echo esc_attr($bphp_style['promo_time_border_radius']); ?>px;
    }
  </style>
  <?php

  if( isset($bphp_style['header_promo_style']) === 'style_3'){ ?>
    <style>
    #promo-outer #close {
        font-size: 15px;
        line-height: 24px;
      }
    </style>
    <?php 
  }
}
add_action( 'wp_head', 'bphp_header_promo_style' );


// Countdown html markup
function bphp_countdown_html_markup() { ?>
    <ul class="countdown">
      <li>
      <span class="days"><?php echo esc_html__('00', 'header-promo'); ?></span><span class="days_ref"><?php echo esc_html__('days', 'header-promo'); ?></span
        ><span class="hours"><?php echo esc_html__('00', 'header-promo'); ?></span> <span class="hours_ref"><?php echo esc_html__('hours', 'header-promo'); ?></span>
        <span class="minutes"><?php echo esc_html__('00', 'header-promo'); ?></span><span class="minutes_ref"><?php echo esc_html__('minutes', 'header-promo'); ?></span
        ><span class="seconds"><?php echo esc_html__('00', 'header-promo'); ?></span><span class="seconds_ref"><?php echo esc_html__('seconds', 'header-promo'); ?></span>
      </li>
    </ul>
<?php
}
// Promo Initial Script
function bphp_header_promo_initial_script() {
  $bphp_script = get_option( 'bphp_promo' );
  ?>
  <script>
    (function($) {
      $('document').ready(function() {
        $(".countdown").downCount(
          {
            date: "<?php echo esc_attr($bphp_script['promo_count_date']); ?> <?php echo esc_attr($bphp_script['promo_count_time']); ?>",
            offset: +10,
          },
          function () {
            alert("PROMOTION, Done!");
          }
        );
      });
    })(jQuery);
</script>
<?php 
}
add_action('wp_footer', 'bphp_header_promo_initial_script');

// After activation redirect
register_activation_hook(__FILE__, 'bphp_plugin_activate');
add_action('admin_init', 'bphp_plugin_redirect');

function bphp_plugin_activate() {
	add_option('bphp_plugin_do_activation_redirect', true);
}

function bphp_plugin_redirect() {
    if (get_option('bphp_plugin_do_activation_redirect', false)) {
        delete_option('bphp_plugin_do_activation_redirect');
        wp_redirect('admin.php?page=bphp-support');
    }
}



// External files Inclusion

// Option panel
require_once 'inc/csf/csf-config.php';
if( class_exists( 'CSF' )) {
  require_once 'inc/csf/setting-options.php';
}
require_once 'admin/ads/submenu.php';



